import re
from render_polargrid.utils import get_settings
from blender_asset_tracer.bpathlib import BlendPath


REGEX_EMAIL = re.compile("""^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$""")
REGEX_TOKEN = re.compile("""^([0-9a-f]){10}$""")
REGEX_SECRET = re.compile("""^([0-9a-f]){110,}$""")


def is_valid_email(email):
    return REGEX_EMAIL.match(email)


def is_valid_token(token):
    return REGEX_TOKEN.match(token)


def is_valid_secret(secret):
    return REGEX_SECRET.match(secret)


def is_preferences_valid(context):
    settings = get_settings(context)
    return all((
        is_valid_email(settings.email),
        is_valid_token(settings.token),
        is_valid_secret(settings.secret),
    ))

def is_valid_project_root(project_root):
    if project_root:
        bpath = BlendPath(str.encode(project_root))
        if bpath.is_blendfile_relative():
            return False

    return True